from ..MetaDataObject import MetaDataObject
from ..MetaDataObject.versions.Template83 import Template83
from ..MetaDataObject.versions.Template82 import Template82
from ..MetaDataObject.versions.Template81 import Template81


class Template(MetaDataObject):

    versions = {
        '81': Template81,
        '82': Template82,
        '83': Template83
    }



from ..MetaDataObject import MetaDataObject
from ..MetaDataObject.versions.CommonTemplate83 import CommonTemplate83


class CommonTemplate(MetaDataObject):

    versions = {
        '83': CommonTemplate83
    }
